R/backend-cached.R
SBC_backend_cached.RdThe cache is stored in files named based on dataset and underlying
backend hashes, within the given directory, you can use
cached_fit_filename() to manually access the cache.
SBC_backend_cached(cache_dir, backend)The cached fit will try to re-emit all output, warnings and messages. The ordering within each category is preserved, but the relative ordering of e.g. outputs vs. messages (and all other combinations) may not be.