Merge two or more datasets of the same length, each generated by a different model. The "true" model will be chosen randomly for each dataset.

SBC_datasets_for_bf(..., probs = NULL, model_var = "model", prob_H1 = NULL)

Details

The merged dataset will keep track of all parameters and later allow splitting results with split_SBC_results_for_bf(), to this, a number of submodel-specific variables will be stored, but marked as hidden_var_attribute() to not clutter default visualisations.