Users should typically not call this method and instead let SBC_backend_bridgesampling() to call it for them.

SBC_fit_to_bridge_sampler(backend, fit, generated, ...)

Arguments

backend

the underlying backend

fit

corresponding to the backend

generated

the generated data used to fit the underlying model

...

passed to bridgesampling::bridge_sampler().

Value

an object of class bridge or bridge_list.