A diagnostic representing count values.

count_diagnostic(
  label,
  error_above = 0,
  label_short = NULL,
  hint = "",
  error_only = FALSE
)

Arguments

label

a description of the diagnostic

error_above

a problem is signalled when the diagnostic is above this value

label_short

optional shorter name for improved messages

hint

a suggestion to the user to show when the diagnostic is problematic

error_only

only report the diagnostic if at least one fit has a problematic value