A backend may optionally implement this method to provide information how the diagnostics reported by the backend can be best summarised and presented to the user. See vignette("implementing_backends") for an example implementation.

diagnostic_types(diags)

Arguments

diags

a data.frame with the diagnostics (and an extra class to trigger the correct S3 method)

Value

A named list where names are columns in the data frame and values are objects that support the get_diagnostic_messages_single() function.