A diagnostic representing binary values.

logical_diagnostic(
  ok_value,
  true_label,
  false_label = paste0("not ", true_label),
  hint = "",
  error_only = FALSE
)

Arguments

ok_value

which value (TRUE or FALSE) signals a problem with the fit

true_label

label to use for positive cases

false_label

label to use for negative cases

hint

a suggestion to the user to show when the diagnostic is problematic

error_only

only report the diagnostic if at least one fit has a problematic value