R/backends.R
SBC_fit_specific_dquants.RdAs of 2026-03 the only use case is computing the top model probability for model selection across multiple models (since model probability is not directly available in normal derived quantities).
SBC_fit_specific_dquants(fit)
# Default S3 method
SBC_fit_specific_dquants(fit)A derived_quantities() object or NULL if there are none