R/backend-bridgesampling.R
SBC_fit_to_bridge_sampler.RdUsers should typically not call this method and instead let
SBC_backend_bridgesampling() to call it for them.
SBC_fit_to_bridge_sampler(backend, fit, generated, ...)the underlying backend
corresponding to the backend
the generated data used to fit the underlying model
passed to bridgesampling::bridge_sampler().
an object of class bridge or bridge_list.