A diagnostic representing count values.
count_diagnostic(
label,
error_above = 0,
label_short = NULL,
hint = "",
error_only = FALSE
)a description of the diagnostic
a problem is signalled when the diagnostic is above this value
optional shorter name for improved messages
a suggestion to the user to show when the diagnostic is problematic
only report the diagnostic if at least one fit has a problematic value