A diagnostic representing binary values.
logical_diagnostic(
ok_value,
true_label,
false_label = paste0("not ", true_label),
hint = "",
error_only = FALSE
)which value (TRUE or FALSE) signals a problem with the fit
label to use for positive cases
label to use for negative cases
a suggestion to the user to show when the diagnostic is problematic
only report the diagnostic if at least one fit has a problematic value