Optionally the message can signal failure if the diagnostic is above/below a certain threshold or is NA.
numeric_diagnostic(
label,
report = NULL,
error_above = Inf,
error_below = -Inf,
allow_na = FALSE,
label_short = NULL,
hint = "",
digits = 2,
unit = ""
)a description of the diagnostic
what value shuld be reported to represent the diagnostic.
Support options are "min", "max" and "quantiles"
signal a problem when the diagnostic is above this value
signal a problem when the diagnostic is below this value
if FALSE, any NA values are reported as a problem
a shorter version of the label (if the original is long) for cleaner summaries.
A suggestion what the user can do if problems are signalled
decimal digits to report
optional unit to report alongside the values